@@ -240,7 +240,7 @@ class TimeSeries(object):
 
         # Append the instrument to the ancilary variables
         av = getattr(datavar, 'ancillary_variables', '')
-        av += ' instrument'
+        av += ' {}'.format(instr_var_name)
         datavar.ancillary_variables = av.strip()
 
         self._nc.sync()
@@ -352,7 +352,7 @@ class TimeSeries(object):
         logger.info("Setting values for {}...".format(variable_name))
         if len(used_values.shape) == 1:
             var = self._nc.createVariable(variable_name, get_type(used_values), ("time",), fill_value=fillvalue, chunksizes=(self.time_chunk,), zlib=True)
-            var.ncei_template_version = 'NCEI_NetCDF_TimeSeries_Orthogonal_Template_v2.0'
+            self._nc.setncattr('ncei_template_version', 'NCEI_NetCDF_TimeSeries_Orthogonal_Template_v2.0')
             if vertical_axis.size == 1:
                 var.coordinates = "{} {} latitude longitude".format(self.time_axis_name, self.vertical_axis_name)
             else:
@@ -379,7 +379,7 @@ class TimeSeries(object):
         elif len(used_values.shape) == 2:
             var = self._nc.createVariable(variable_name, get_type(used_values), ("time", "z",), fill_value=fillvalue, chunksizes=(self.time_chunk, vertical_axis.size,), zlib=True)
             var.coordinates = "{} {} latitude longitude".format(self.time_axis_name, self.vertical_axis_name)
-            var.ncei_template_version = 'NCEI_NetCDF_TimeSeriesProfile_Orthogonal_Template_v2.0'
+            self._nc.setncattr('ncei_template_version', 'NCEI_NetCDF_TimeSeriesProfile_Orthogonal_Template_v2.0')
         else:
             raise ValueError("Could not create variable.  Shape of data is {!s}.  Expected a dimension of 1 or 2, not {!s}.".format(used_values.shape, len(used_values.shape)))
 
@@ -513,14 +513,14 @@ class TimeSeries(object):
         self._nc.setncattr("time_coverage_start",    starting.isoformat())
         self._nc.setncattr("time_coverage_end",      ending.isoformat())
         # duration (ISO8601 format)
-        self._nc.setncattr("time_coverage_duration", "P%sS" % str(int(round((ending - starting).total_seconds()))))
+        self._nc.setncattr("time_coverage_duration", "PT{0:d}S".format(int(round((ending - starting).total_seconds()))))
         # resolution (ISO8601 format)
         # subtract adjacent times to produce an array of differences, then get the most common occurance
         diffs = unique_times[1:] - unique_times[:-1]
         uniqs, inverse = np.unique(diffs, return_inverse=True)
         if uniqs.size > 1:
             time_diffs = diffs[np.bincount(inverse).argmax()]
-            self._nc.setncattr("time_coverage_resolution", "P%sS" % str(int(round(time_diffs))))
+            self._nc.setncattr("time_coverage_resolution", "PT{0:d}S".format(int(round(time_diffs))))
 
         # Time
         self.time_chunk = min(full_times.size, 1000)
